/*!
 * @file fi_pci.h
 * @brief Header file for the Fastec PCI driver.
 *
 * This file includes the definitions and function prototypes for
 * the external facing features of the driver. It may be used by
 * internal (i.e. PCI driver) routines, but it is also expected
 * that external drivers will include this header file to
 * have the declarations needed to interact with the PCI driver.
 *
 * Copyright (C) 2017 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef _FASTEC_PCI_H
#define _FASTEC_PCI_H

// Only for Linux Kernel
#ifdef __KERNEL__

// -----------------------------------------------------------------------
// Includes
// -----------------------------------------------------------------------

// -----------------------------------------------------------------------
// Constant Definitions
// -----------------------------------------------------------------------

//! The callback template.
typedef void (*PCI_CALLBACK)(u32 irq_status);

// -----------------------------------------------------------------------
// Function Prototypes
// -----------------------------------------------------------------------

//! @{
//! External function declarations for use by other drivers.
extern uint32_t *fi_pci_get_base(void);      // BAR[0]
extern uint32_t *fi_pci_get_im_fifo(void);   // BAR[BAR_SEL]
extern uint64_t fi_pci_get_imbase(void);     // PC's image memory.

extern void fi_pci_add_callback(PCI_CALLBACK cb, u32 mask);
extern void fi_pci_remove_callback(PCI_CALLBACK cb);
//
//! @}

#endif /* __KERNEL__ */
#endif /* _FASTEC_PCI_H */
